@@ -40,10 +40,10 @@ RcppExport SEXP Rarea(SEXP mesh_, SEXP report_= wrap(true)) {
 			  );
 			      
   } catch (std::exception& e) {
-    ::Rf_error( e.what());
+    forward_exception_to_r( e );
     return wrap(1);
   } catch (...) {
     ::Rf_error("unknown exception");
-  }
+  } return R_NilValue; // -Wall
 }
 
