@@ -18,10 +18,10 @@ RcppExport SEXP RSphere(SEXP subdiv_ = wrap(3),SEXP normals_ = wrap(true)) {
     List out = Rvcg::IOMesh<MyMesh>::RvcgToR(m,normals);
     return out;
   } catch (std::exception& e) {
-    ::Rf_error( e.what());
+    forward_exception_to_r( e );
   } catch (...) {
     ::Rf_error("unknown exception");
-  }
+  } return R_NilValue; 
 }
 
 RcppExport SEXP RSphericalCap(SEXP angleRad_,SEXP subdiv_ = wrap(3), SEXP normals_ = wrap(true)) {
@@ -41,10 +41,10 @@ RcppExport SEXP RSphericalCap(SEXP angleRad_,SEXP subdiv_ = wrap(3), SEXP normal
     List out = Rvcg::IOMesh<MyMesh>::RvcgToR(m,normals);
     return out;
   } catch (std::exception& e) {
-    ::Rf_error( e.what());
+    forward_exception_to_r( e );
   } catch (...) {
     ::Rf_error("unknown exception");
-  }
+  } return R_NilValue; 
 }
 
 RcppExport SEXP RTetrahedron(SEXP normals_ = wrap(true)) {
@@ -56,10 +56,10 @@ RcppExport SEXP RTetrahedron(SEXP normals_ = wrap(true)) {
       tri::UpdateNormal<MyMesh>::PerVertexNormalized(m);
     return Rvcg::IOMesh<MyMesh>::RvcgToR(m,normals);
   } catch (std::exception& e) {
-    ::Rf_error( e.what());
+    forward_exception_to_r( e );
   } catch (...) {
     ::Rf_error("unknown exception");
-  }
+  } return R_NilValue; 
 }
 
 RcppExport SEXP RDodecahedron(SEXP normals_ = wrap(true)) {
@@ -79,10 +79,10 @@ RcppExport SEXP ROctahedron(SEXP normals_ = wrap(true)) {
       tri::UpdateNormal<MyMesh>::PerVertexNormalized(m);
     return Rvcg::IOMesh<MyMesh>::RvcgToR(m,normals);
   } catch (std::exception& e) {
-    ::Rf_error( e.what());
+    forward_exception_to_r( e );
   } catch (...) {
     ::Rf_error("unknown exception");
-  }
+  } return R_NilValue; 
 }
 
 RcppExport SEXP RIcosahedron(SEXP normals_ = wrap(true)) {
@@ -94,10 +94,10 @@ RcppExport SEXP RIcosahedron(SEXP normals_ = wrap(true)) {
       tri::UpdateNormal<MyMesh>::PerVertexNormalized(m);
     return Rvcg::IOMesh<MyMesh>::RvcgToR(m,normals);
   } catch (std::exception& e) {
-    ::Rf_error( e.what());
+    forward_exception_to_r( e );
   } catch (...) {
     ::Rf_error("unknown exception");
-  }
+  } return R_NilValue; 
 }
 
 
@@ -111,10 +111,10 @@ RcppExport SEXP RHexahedron(SEXP normals_ = wrap(true)) {
       tri::UpdateNormal<MyMesh>::PerVertexNormalized(m);
     return Rvcg::IOMesh<MyMesh>::RvcgToR(m,normals);
   } catch (std::exception& e) {
-    ::Rf_error( e.what());
+    forward_exception_to_r( e );
   } catch (...) {
     ::Rf_error("unknown exception");
-  }
+  } return R_NilValue; 
 }
 
 RcppExport SEXP RSquare(SEXP normals_ = wrap(true)) {
@@ -126,10 +126,10 @@ RcppExport SEXP RSquare(SEXP normals_ = wrap(true)) {
       tri::UpdateNormal<MyMesh>::PerVertexNormalized(m);
     return Rvcg::IOMesh<MyMesh>::RvcgToR(m,normals);
   } catch (std::exception& e) {
-    ::Rf_error( e.what());
+    forward_exception_to_r( e );
   } catch (...) {
     ::Rf_error("unknown exception");
-  }
+  } return R_NilValue; 
 }
 
 RcppExport SEXP RBox(SEXP mesh_,SEXP normals_ = wrap(true)) {
@@ -145,10 +145,10 @@ RcppExport SEXP RBox(SEXP mesh_,SEXP normals_ = wrap(true)) {
       tri::UpdateNormal<MyMesh>::PerVertexNormalized(m);
     return Rvcg::IOMesh<MyMesh>::RvcgToR(m,normals);
   } catch (std::exception& e) {
-    ::Rf_error( e.what());
+    forward_exception_to_r( e );
   } catch (...) {
     ::Rf_error("unknown exception");
-  }
+  } return R_NilValue; 
 }
 
 RcppExport SEXP RCone(SEXP r1_, SEXP r2_, SEXP h_, SEXP normals_ = wrap(true)) {
@@ -163,8 +163,8 @@ RcppExport SEXP RCone(SEXP r1_, SEXP r2_, SEXP h_, SEXP normals_ = wrap(true)) {
       tri::UpdateNormal<MyMesh>::PerVertexNormalized(m);
     return Rvcg::IOMesh<MyMesh>::RvcgToR(m,normals);
   } catch (std::exception& e) {
-    ::Rf_error( e.what());
+    forward_exception_to_r( e );
   } catch (...) {
     ::Rf_error("unknown exception");
-  }
+  } return R_NilValue; 
 }
